| Title: | Run some basic security checks before installing R packages from online repositories |
|---|---|
| Description: | Run some basic security checks before installing R packages from online repositories. |
| Authors: | Francisco Rodriguez-Sanchez [aut, cre] |
| Maintainer: | Francisco Rodriguez-Sanchez <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-13 07:23:09 UTC |
| Source: | https://github.com/Pakillo/safeinstall |
Check a package repository for potential security issues
check_package(repo = NULL, verbose = TRUE)check_package(repo = NULL, verbose = TRUE)
repo |
Link to an online git repository (e.g. "https://github.com/Pakillo/safeinstall.git") |
verbose |
Logical. Show verbose output? |
TRUE if the package passes the security checks, otherwise FALSE (and some extra information about potential issues if verbose = TRUE).
## Not run: library(safeinstall) check_package("https://github.com/Pakillo/safeinstall.git") check_package("https://github.com/ropenscilabs/testevil.git") ## End(Not run)## Not run: library(safeinstall) check_package("https://github.com/Pakillo/safeinstall.git") check_package("https://github.com/ropenscilabs/testevil.git") ## End(Not run)
Safe installation of R packages from GitHub
safe_install_github(user.repo = NULL, ..., verbose = TRUE)safe_install_github(user.repo = NULL, ..., verbose = TRUE)
user.repo |
Repository address in the format |
... |
Further options passed to |
verbose |
Logical. Show verbose output? |
If no unsafe code is detected, the package is installed. Otherwise, an error message calling to inspect the repository for potential problems.
## Not run: library(safeinstall) safe_install_github("Pakillo/safeinstall") safe_install_github("ropenscilabs/testevil") ## End(Not run)## Not run: library(safeinstall) safe_install_github("Pakillo/safeinstall") safe_install_github("ropenscilabs/testevil") ## End(Not run)